@@ -63,8 +63,8 @@ from .extra import EXTRA_APPS, EXTRA_ADMINS
 # context_processors
 DEPLOYMENT_ENV = env("DEPLOYMENT_ENV", default='dev' if DEBUG else 'production')
 REPOSITORY_REV = env("REPOSITORY_REV", default=None)
-EMAILS_DOMAIN = env('EMAILS_DOMAIN', default=APP_DOMAIN) # domain name specified in email templates
-EMAILS_SITE_NAME = env('EMAILS_SITE_NAME', default=COOKIE_DOMAIN) # site name specified in email templates
+EMAILS_DOMAIN = env('EMAILS_DOMAIN', default=APP_DOMAIN)  # domain name specified in email templates
+EMAILS_SITE_NAME = env('EMAILS_SITE_NAME', default=COOKIE_DOMAIN)  # site name specified in email templates
 GOOGLE_API_KEY = env('GOOGLE_API_KEY', default='undefined')
 GOOGLE_MAPS_API_VERSION = env('GOOGLE_MAPS_API_VERSION', default='3.34')
 GOOGLE_ANALYTICS_TRACKING_ID = env('GOOGLE_ANALYTICS_TRACKING_ID', default='')
@@ -118,7 +118,7 @@ DJANGO_APPS = [
     "django.contrib.sites",
     "django.contrib.messages",
     "django.contrib.staticfiles",
-    # "django.contrib.humanize", # Handy template tags
+    "django.contrib.humanize", # Handy template tags
     "django.contrib.admin",
     "django.forms",
     "django.contrib.flatpages",
@@ -141,6 +141,8 @@ THIRD_PARTY_APPS = [
     "rpc4django",
 
     "drf_yasg",
+
+    "django_project_backup"
 ]
 
 LOCAL_APPS = [
@@ -165,7 +167,7 @@ AUTHENTICATION_BACKENDS = [
 # https://docs.djangoproject.com/en/dev/ref/settings/#auth-user-model
 AUTH_USER_MODEL = "users.User"
 # https://docs.djangoproject.com/en/dev/ref/settings/#login-redirect-url
-LOGIN_REDIRECT_URL = "/profile/"
+LOGIN_REDIRECT_URL = "/"
 # https://docs.djangoproject.com/en/dev/ref/settings/#login-url
 LOGIN_URL = "account_login"
 
@@ -209,8 +211,10 @@ MIDDLEWARE = [
     "django.middleware.locale.LocaleMiddleware",
     "django.middleware.common.CommonMiddleware",
     "django.middleware.csrf.CsrfViewMiddleware",
-    "django.contrib.auth.middleware.AuthenticationMiddleware",
-    "django_sso_app.core.middleware.authentication.DjangoSsoAppAuthenticationMiddleware",  # django-sso-app
+
+    "django.contrib.auth.middleware.AuthenticationMiddleware",  # required by django-sso-app
+    "django_sso_app.core.authentication.middleware.DjangoSsoAppAuthenticationMiddleware",  # django-sso-app
+
     "django.contrib.messages.middleware.MessageMiddleware",
     "django.middleware.common.BrokenLinkEmailsMiddleware",
     "django.middleware.clickjacking.XFrameOptionsMiddleware",
@@ -255,12 +259,19 @@ MEDIA_URL = "/media/"
 # TEMPLATES
 # ------------------------------------------------------------------------------
 # https://docs.djangoproject.com/en/dev/ref/settings/#templates
+
+if DJANGO_SSO_APP_BACKEND_CUSTOM_FRONTEND_APP:
+    _TEMPLATE_DIRS = []
+else:
+    _TEMPLATE_DIRS = [str(BACKEND_DIR.path("templates"))]
+
+
 TEMPLATES = [
     {
         # https://docs.djangoproject.com/en/dev/ref/settings/#std:setting-TEMPLATES-BACKEND
         "BACKEND": "django.template.backends.django.DjangoTemplates",
         # https://docs.djangoproject.com/en/dev/ref/settings/#template-dirs
-        "DIRS": [str(BACKEND_DIR.path("templates"))],
+        "DIRS": _TEMPLATE_DIRS,
         "OPTIONS": {
             # https://docs.djangoproject.com/en/dev/ref/settings/#template-loaders
             # https://docs.djangoproject.com/en/dev/ref/templates/api/#loader-types
@@ -308,9 +319,9 @@ CRISPY_TEMPLATE_PACK = "bootstrap4"
 # SECURITY
 # ------------------------------------------------------------------------------
 # https://docs.djangoproject.com/en/dev/ref/settings/#session-cookie-httponly
-SESSION_COOKIE_HTTPONLY = True
+SESSION_COOKIE_HTTPONLY = False if DEBUG else True
 # https://docs.djangoproject.com/en/dev/ref/settings/#csrf-cookie-httponly
-CSRF_COOKIE_HTTPONLY = True
+CSRF_COOKIE_HTTPONLY = False if DEBUG else True
 # https://docs.djangoproject.com/en/dev/ref/settings/#secure-browser-xss-filter
 SECURE_BROWSER_XSS_FILTER = True
 # https://docs.djangoproject.com/en/dev/ref/settings/#x-frame-options
@@ -326,16 +337,18 @@ if DEBUG:
     CORS_ORIGIN_ALLOW_ALL = True
     CSRF_TRUSTED_ORIGINS = []
 else:
-    CSRF_COOKIE_DOMAIN = APP_DOMAIN
+    CSRF_COOKIE_DOMAIN = COOKIE_DOMAIN
     CSRF_TRUSTED_ORIGINS = ['.{0}'.format(COOKIE_DOMAIN)]
 
 # cors
 if DEBUG:
-    CORS_ORIGIN_ALLOW_ALL = True
+    """CORS_ORIGIN_ALLOW_ALL = True"""
+    CORS_ORIGINS = ['localhost:8000', 'localhost:6060', 'bs-local.com:8000']
+    CORS_ALLOW_CREDENTIALS = True
 else:
     # https://github.com/ottoyiu/django-cors-headers
     # CORS headers defaults to 'accounts.example.com'
-    _CORS_ORIGINS = env("CORS_ORIGINS", default='{0}://{1}'.format(ACCOUNT_DEFAULT_HTTP_PROTOCOL, COOKIE_DOMAIN))
+    _CORS_ORIGINS = env("CORS_ORIGINS", default='{0}://{1}'.format(ACCOUNT_DEFAULT_HTTP_PROTOCOL, APP_DOMAIN))
     CORS_ORIGIN_WHITELIST = list(map(lambda x: '{}'.format(x.replace(' ', '')), _CORS_ORIGINS.split(',')))
     #CORS_ORIGIN_WHITELIST = _CORS_ORIGINS.split(',')
     CORS_ALLOW_CREDENTIALS = True
