@@ -138,11 +138,12 @@ class AppSettings(object):
                                                 'latitude', 'longitude',
                                                 'country',
                                                 'address',
-                                                'language'), tuple)
+                                                'language',
+                                                'alias'), tuple)
 
     @property
     def REQUIRED_PROFILE_FIELDS(self):
-        return self._setting('REQUIRED_PROFILE_FIELDS', (), tuple)
+        return self._setting('REQUIRED_PROFILE_FIELDS', ('first_name', ), tuple)
 
     @property
     def HTTP_PROTOCOL(self):
@@ -170,7 +171,7 @@ class AppSettings(object):
 
     @property
     def LOGIN_MUST_FILL_PROFILE(self):
-        return self._setting('LOGIN_MUST_FILL_PROFILE', False, bool)
+        return self._setting('LOGIN_MUST_FILL_PROFILE', True, bool)
 
     @property
     def MANAGE_USER_GROUPS(self):
@@ -259,6 +260,14 @@ class AppSettings(object):
     def BACKEND_URL(self):
         return self._setting('BACKEND_URL', self.HTTP_PROTOCOL + '://' + self.BACKEND_DOMAIN)
 
+    @property
+    def PROFILE_UPDATE_URL(self):
+        return self._setting('PROFILE_UPDATE_URL', '/profile/update/')
+
+    @property
+    def PROFILE_COMPLETE_URL(self):
+        return self._setting('PROFILE_COMPLETE_URL', '/profile/complete/')
+
     @property
     def REMOTE_USERS_URL(self):
         return self.BACKEND_URL + '/api/v1/auth/users/'
@@ -299,6 +308,10 @@ class AppSettings(object):
     def REMOTE_PROFILE_UPDATE_URL(self):
         return self.BACKEND_URL + '/profile/update/'
 
+    @property
+    def REMOTE_PROFILE_COMPLETE_URL(self):
+        return self.BACKEND_URL + '/profile/complete/'
+
     @property
     def I18N_PATH_ENABLED(self):
         return self._django_setting('I18N_PATH_ENABLED', I18N_PATH_ENABLED, bool)
@@ -325,7 +338,11 @@ class AppSettings(object):
 
     @property
     def LOGOUT_DELETES_ALL_PROFILE_DEVICES(self):
-        return self._setting('LOGOUT_DELETES_ALL_PROFILE_DEVICES', True, bool)
+        return self._setting('LOGOUT_DELETES_ALL_PROFILE_DEVICES', False, bool)
+
+    @property
+    def USER_TYPES(self):
+        return self._setting('USER_TYPES', [], list)
 
 
 # Ugly? Pennersr says Guido recommends this himself ...
