@@ -10,6 +10,25 @@ logger = logging.getLogger('django_sso_app.core.apps.api_gateway.kong')
 User = get_user_model()
 
 
+def get_apigw_consumer(profile):
+    logger.info('getting apigw consumer for {}'.format(profile))
+
+    consumer_id = get_apigateway_consumer_id(profile.sso_id)
+
+    url = app_settings.APIGATEWAY_HOST + "/consumers/{}".format(consumer_id)
+    r = requests.get(url)
+
+    response_body = None
+    status_code = r.status_code
+    try:
+        response_body = r.json()
+    except:
+        logger.info('Response ({}) has no payload'.format(status_code))
+
+    logger.info('apigw response ({0}) {1}'.format(status_code, response_body))
+    return status_code, response_body
+
+
 def create_apigw_consumer(profile):
     logger.info('creating apigw consumer for {}'.format(profile))
 
@@ -142,17 +161,31 @@ def delete_apigw_consumer_acl(profile, group_name):
 
 
 def get_profile_apigw_consumer_id(profile, force_recreate=False):
+
     if profile.apigw_consumer_id is None or force_recreate:
-        logger.info('Profile "{}" has no apigateway_consumer_id, creating'.format(profile))
+        logger.info('Profile "{}" has no apigateway_consumer_id, checking if exists or creating new'.format(profile))
 
-        status_code_1, consumer = create_apigw_consumer(profile)
-        if status_code_1 != 201:
-            logger.error('Error ({0}) creating apigw consumer, {1}'.format(
-                status_code_1, consumer))
-            raise Exception(
-                "Error ({0}) creating apigw consumer, {1}".format(
+        # try to find an existent consumer
+        status_code_0, consumer = get_apigw_consumer(profile)
+        if status_code_0 == 404:
+            logger.info('No apigw consumer found for profile "{}", creating'.format(profile))
+
+            # creating new
+            status_code_1, consumer = create_apigw_consumer(profile)
+            if status_code_1 != 201:
+                logger.error('Error ({0}) creating apigw consumer, {1}'.format(
                     status_code_1, consumer))
+                raise Exception(
+                    "Error ({0}) creating apigw consumer, {1}".format(
+                        status_code_1, consumer))
 
+        elif status_code_0 == 200:
+            logger.info('Consumer "{}" found for profile "{}"'.format(consumer, profile))
+        else:
+            raise Exception(
+                "Error ({0}) getting apigw consumer, {1}".format(status_code_0, consumer))
+
+        # adding profile to groups
         profile_groups = [app_settings.APIGATEWAY_CONSUMER_GROUP] + \
                          list(profile.user.groups.values_list('name', flat=True))
 
@@ -167,10 +200,10 @@ def get_profile_apigw_consumer_id(profile, force_recreate=False):
                     "Error {0} creating apigw consumer acl, {1}".format(
                         status_code_2, acl))
 
-        profile.apigw_consumer_id = consumer['id']
-
+        # Inhibite sso_rev update
         setattr(profile.user, '__dssoa__apigateway_update', True)
-
+        # saving profile
+        profile.apigw_consumer_id = consumer['id']
         profile.save()
 
     else:
