@@ -8,7 +8,7 @@ class Command(BaseCommand):
     help = 'Sets apigw_consumer_id to "None"'
 
     def handle(self, *args, **options):
-        users = User.objects.filter(is_superuser=False)
+        users = User.objects.filter(is_staff=False, is_superuser=False)
         users_count = users.count()
         updated_users = 0
 
