@@ -3,6 +3,7 @@ import logging
 from django.contrib.auth import get_user_model
 from django.db.models.signals import m2m_changed
 from django.db.models.signals import pre_delete, pre_save
+from django.contrib.auth.signals import user_logged_in
 from django.dispatch import receiver
 
 from allauth.account.adapter import get_adapter
@@ -23,20 +24,20 @@ adapter = get_adapter()
 
 @receiver(pre_save, sender=Device)
 def create_device_apigw_jwt(sender, instance, **kwargs):
-    profile = instance.profile
+    device = instance
+    profile = device.profile
     user = profile.user
 
     if not is_django_staff(user):
-        apigateway_consumer_id = get_profile_apigw_consumer_id(profile)
+        logger.info('Profile "{}" has apigw_consumer_id "{}"'.format(profile, profile.apigw_consumer_id))
 
-        logger.info('Profile "{}" has apigateway_consumer_id "{}"'.format(profile, apigateway_consumer_id))
+        apigateway_consumer_id = get_profile_apigw_consumer_id(profile)
+        logger.info('apigateway_consumer_id "{}" on device create'.format(apigateway_consumer_id))
 
         if instance._state.adding:
-            device = instance
-
             logger.info('Creating apigw JWT for Device "{}"'.format(device))
 
-            status_code, r1 = create_apigw_consumer_jwt(device.profile)
+            status_code, r1 = create_apigw_consumer_jwt(profile)
             if status_code != 201:
                 # delete_apigw_consumer(username)
                 logger.error(
@@ -68,7 +69,7 @@ def delete_device_api_jwt(sender, instance, **kwargs):
 # profile
 
 @receiver(pre_delete, sender=Profile)
-def delete_apigw_user_consumer(sender, instance, **kwargs):
+def delete_apigw_profile_consumer(sender, instance, **kwargs):
     user = instance.user
 
     if not is_django_staff(user):
@@ -106,7 +107,7 @@ def signal_handler_when_profile_is_added_to_or_removed_from_group(action, instan
                     status_code, resp = create_apigw_consumer_acl(profile, group.name)
 
                     if status_code == 201:
-                        logger.info('api gateway acl goup created {}, {}'.format(status_code, resp))
+                        logger.info('api gateway acl group created {}, {}'.format(status_code, resp))
 
                         if not is_loaddata:
                             profile.update_rev(True)
@@ -127,3 +128,26 @@ def signal_handler_when_profile_is_added_to_or_removed_from_group(action, instan
                             profile.update_rev(True)
                     else:
                         logger.exception('error ({}) creating api gateway acl group'.format(status_code))
+
+
+@receiver(user_logged_in)
+def post_user_login(**kwargs):
+    user = kwargs['user']
+
+    if not is_django_staff(user):
+        # request = kwargs['request']
+        profile = user.sso_app_profile
+
+        apigateway_consumer_id = get_profile_apigw_consumer_id(profile)
+        logger.info('apigateway_consumer_id on login "{}"'.format(apigateway_consumer_id))
+
+        for group in profile.groups.all():
+            # try create apigw consumer acls for logged in user
+            
+            status_code, resp = create_apigw_consumer_acl(profile, group.name)
+
+            if status_code == 201:
+                logger.info('apigateway acl group "{}" created on login'.format(group.name))
+
+            else:
+                logger.exception('apigateway acl group "{}" not created on login ({})'.format(group.name, status_code))
