@@ -39,10 +39,18 @@ class ProfileSerializer(AbsoluteUrlSerializer):
     language = serializers.CharField(required='language' in app_settings.REQUIRED_PROFILE_FIELDS,
                                      allow_null=True)
 
+    alias = serializers.CharField(required='alias' in app_settings.REQUIRED_PROFILE_FIELDS,
+                                  allow_null=True)
+
     # role = serializers.IntegerField(required='role' in app_settings.REQUIRED_PROFILE_FIELDS)
 
     groups = serializers.SerializerMethodField(required=False)
 
+    meta = serializers.SerializerMethodField(required=False)
+
+    is_incomplete = serializers.SerializerMethodField(required=False)
+    required_fields = serializers.SerializerMethodField(required=False)
+
     class Meta:
         model = Profile
         read_only_fields = (
@@ -53,7 +61,9 @@ class ProfileSerializer(AbsoluteUrlSerializer):
             'is_unsubscribed',
             'username', 'email',
             'user',
-            'groups') + app_settings.USER_FIELDS
+            'groups',
+            'meta',
+            'is_incomplete', 'required_fields') + app_settings.USER_FIELDS
         fields = read_only_fields + app_settings.PROFILE_FIELDS
 
     def get_groups(self, instance):
@@ -71,6 +81,19 @@ class ProfileSerializer(AbsoluteUrlSerializer):
                 })
         return serialized
 
+    def get_is_incomplete(self, instance):
+        return instance.is_incomplete
+
+    def get_required_fields(self, instance):
+        serialized = []
+        if app_settings.BACKEND_ENABLED:
+            if instance.is_incomplete:
+                for field in app_settings.REQUIRED_PROFILE_FIELDS:
+                    if getattr(instance, field, None) in [None, '']:
+                        serialized.append(field)
+
+        return serialized
+
     def get_absolute_rest_url(self, obj):
         if getattr(obj, 'id', None) is not None:
             request = self.context['request']
@@ -86,6 +109,9 @@ class ProfileSerializer(AbsoluteUrlSerializer):
         except:
             logger.warning('No profile.user url for {}.'.format(instance))
 
+    def get_meta(self, instance):
+        return instance.meta
+
 
 class ProfilePublicSerializer(ProfileSerializer, PartialObjectSerializer):
 
