@@ -1,6 +1,5 @@
 import logging
 
-from allauth.account.adapter import get_adapter
 from django.contrib.auth import get_user_model
 from django.shortcuts import reverse, redirect
 from django.urls import reverse_lazy
@@ -13,6 +12,10 @@ from rest_framework import viewsets
 from rest_framework.response import Response
 from rest_framework import generics
 
+from django_filters.rest_framework import DjangoFilterBackend
+
+from allauth.account.adapter import get_adapter
+
 from .forms import UserProfileForm
 from .models import Profile
 from .serializers import ProfileSerializer, ProfilePublicSerializer, ProfileUnsubscriptionSerializer
@@ -22,6 +25,8 @@ from ...permissions import is_staff, is_authenticated
 from ...utils import invalidate_cookie
 from ...mixins import WebpackBuiltTemplateViewMixin
 
+from .filters import ProfileFilter
+
 User = get_user_model()
 
 logger = logging.getLogger('django_sso_app.core.apps.profiles')
@@ -68,7 +73,7 @@ class ProfileUpdateView(LoginRequiredMixin, UpdateView, WebpackBuiltTemplateView
     template_name = "account/profile_update.html"
     form_class = UserProfileForm
 
-    success_url = reverse_lazy('profile.update')
+    success_url = reverse_lazy('profile')
 
     def get_object(self, queryset=None):
         request_user = getattr(self.request, 'user', None)
@@ -113,11 +118,33 @@ class ProfileUpdateView(LoginRequiredMixin, UpdateView, WebpackBuiltTemplateView
             return response
 
 
+class ProfileCompleteView(ProfileUpdateView):
+    template_name = "account/profile_complete.html"
+
+    def get(self, request, *args, **kwargs):
+        logger.info('Getting profile complete')
+
+        if not request.user.sso_app_profile.is_incomplete:
+            return redirect(reverse('profile.update'))
+
+        return super(ProfileCompleteView, self).get(request, *args, **kwargs)
+
+    def post(self, request, *args, **kwargs):
+        logger.info('Posting profile create')
+
+        if not request.user.sso_app_profile.is_incomplete:
+            return redirect(reverse('profile.update'))
+
+        return super(ProfileCompleteView, self).post(request, *args, **kwargs)
+
+
 # api
 
 class ProfileApiViewSet(viewsets.ModelViewSet):
     lookup_field = 'sso_id'
     permission_classes = (permissions.IsAuthenticated, )
+    filter_backends = (DjangoFilterBackend,)
+    filter_class = ProfileFilter
 
     def get_queryset(self):
         requesting_user = self.request.user
