@@ -35,7 +35,8 @@ class DjangoSsoAppUserModelMixin(object):
 
     @property
     def email_has_been_updated(self):
-        return getattr(self, '__dssoa__old_email', None) != self.email
+        return getattr(self, '__dssoa__old_email', None) != self.email or \
+               getattr(self, '__dssoa__email_updated', False)
 
     @property
     def sso_app_new_email(self):
@@ -44,7 +45,8 @@ class DjangoSsoAppUserModelMixin(object):
 
     @property
     def username_has_been_updated(self):
-        return getattr(self, '__dssoa__old_username', None) != self.username
+        return getattr(self, '__dssoa__old_username', None) != self.username or \
+               getattr(self, '__dssoa__username_updated', False)
 
     @property
     def sso_app_new_username(self):
