@@ -79,6 +79,9 @@ class UserProfileSerializer(AbsoluteUrlSerializer):
     language = serializers.CharField(required='language' in app_settings.REQUIRED_PROFILE_FIELDS,
                                      allow_null=True)
 
+    alias = serializers.CharField(required='alias' in app_settings.REQUIRED_PROFILE_FIELDS,
+                                  allow_null=True)
+
     class Meta:
         model = Profile
         read_only_fields = (
@@ -115,9 +118,8 @@ class UserSerializer(AbsoluteUrlSerializer):
             'sso_id', 'sso_rev',
             'date_joined',
             'is_active', 'email_verified',
-            'groups',
-            'profile')
-        fields = read_only_fields + app_settings.USER_FIELDS + ('password', )
+            'groups')
+        fields = read_only_fields + app_settings.USER_FIELDS + ('password', 'profile')
 
     def get_sso_id(self, instance):
         return instance.sso_id
@@ -166,14 +168,18 @@ class UserSerializer(AbsoluteUrlSerializer):
         adapter = get_adapter(request=request)
 
         requesting_user_is_staff = is_staff(requesting_user)
+
         skip_confirmation = request.GET.get('skip_confirmation', None)
         must_confirm_email = True
         if requesting_user_is_staff and skip_confirmation is not None:
             must_confirm_email = False
+
         password_is_hashed = request.query_params.get('password_is_hashed', None)
 
         new_email = validated_data.get('email', None)
         new_password = validated_data.get('password', None)
+        new_username = validated_data.get('username', None)
+        updated_profile = request.data.get('profile', None)
 
         logger.info('User "{}" wants to update user "{}"'.format(requesting_user, user))
 
@@ -194,14 +200,15 @@ class UserSerializer(AbsoluteUrlSerializer):
 
             if must_confirm_email:
                 logger.info('"{}" must confirm email "{}"'.format(user, new_email))
+
+                user.sso_app_profile.update_rev(True)
+
             else:
                 logger.info('confirming email "{}"'.format(new_email))
                 created_email.verified = True
                 created_email.set_as_primary(conditional=False)
 
-            user.email = new_email  # set user model email
-
-            set_session_key(request, '__dssoa__user_email_updated', True)
+                adapter.update_user_email(user, new_email)
 
         if new_password is not None:
             logger.info('user "{}" is changing password for user "{}"'.format(requesting_user,
@@ -214,8 +221,30 @@ class UserSerializer(AbsoluteUrlSerializer):
                 logger.info('password is plain')
                 user.set_password(new_password)
 
-        # finally updating user model
-        user.save()
+            set_session_key(request, '__dssoa__user_password_updated', True)
+
+            user.save()
+
+        if new_username is not None and not user.sso_app_profile.completed_at:
+            logger.info('user "{}" is changing username for user "{}"'.format(requesting_user,
+                                                                              user))
+
+            try:
+                adapter.clean_username(new_username)
+
+            except forms.ValidationError:
+                logger.warning('Can\'t set username as "{}" for user "{}"'.format(new_username, user))
+                raise
+
+            else:
+                adapter.update_user_username(user, new_username)
+
+        if updated_profile is not None:
+            logger.info('user "{}" is updating profile for user "{}"'.format(requesting_user,
+                                                                             user))
+
+            # setting new_user profile serializer field
+            setattr(user, 'sso_app_profile', update_profile(user.sso_app_profile, updated_profile))
 
         return user
 
