@@ -47,14 +47,14 @@ def fetch_remote_user(sso_id, encoded_jwt=None):
 
 
 def update_user(user, update_object, commit=True):
-    logger.info('Updating user fields for "{}"'.format(user))
+    logger.info('Updating user fields for user "{}"'.format(user))
 
     for f in app_settings.USER_FIELDS + ('password', 'is_active', 'date_joined'):
         if hasattr(user, f):
             new_val = update_object.get(f, None)
             if new_val is not None:
                 setattr(user, f, new_val)
-                logger.debug('profile field updated "{}":"{}"'.format(f, new_val if f != 'password' else '*'))
+                logger.debug('user field updated "{}":"{}"'.format(f, new_val if f != 'password' else '*'))
 
     if commit:
         user.save()
@@ -140,7 +140,6 @@ def create_local_user_from_object(user_object, verified=False):
     logger.info('Creating local user from object "{}". Verified: {}'.format(user_object, verified))
 
     username = user_object.get('username')
-    email = user_object.get('email')
     sso_id = user_object.get('sso_id', None)
     sso_rev = user_object.get('sso_rev', 0)
 
@@ -155,15 +154,16 @@ def create_local_user_from_object(user_object, verified=False):
     if User.objects.filter(username=username).count() > 0:
         raise Exception('User with username "{}" already present'.format(username))
 
-    if User.objects.filter(email=email).count() > 0:
-        raise Exception('User with email "{}" already present'.format(email))
-
     new_user = User()
 
+    user_object_profile = user_object.get('profile', None)
+
     setattr(new_user, '__dssoa__creating', True)
     setattr(new_user, '__dssoa__profile__sso_id', sso_id)
     setattr(new_user, '__dssoa__profile__sso_rev', sso_rev)
 
+    setattr(new_user, '__dssoa__profile__object', user_object_profile)
+
     # saving model there (commit) implies profile creation with pre-defined attrs sso_id, sso_rev
     new_user = update_user(new_user, user_object, commit=True)
 
@@ -195,16 +195,13 @@ def create_local_user_from_object(user_object, verified=False):
 
 
 @transaction.atomic
-def create_local_user_from_remote_backend(remote_user, can_subscribe=False):
+def create_local_user_from_remote_backend(remote_user_object, can_subscribe=False):
     # Creates new user only by profile object
-    remote_user_profile_object = remote_user.get('profile')
 
-    new_user = create_local_user_from_object(remote_user_profile_object,
-                                             verified=getattr(remote_user, 'email_verified', False))
+    new_user = create_local_user_from_object(remote_user_object,
+                                             verified=getattr(remote_user_object, 'email_verified', False))
 
-    setattr(new_user, '__dssoa__remote_user', remote_user)  # noqa (subscription required)
-
-    setattr(new_user, 'sso_app_profile', get_or_create_user_profile(new_user, Profile, remote_user_profile_object))
+    setattr(new_user, '__dssoa__remote_user', remote_user_object)  # noqa (subscription required)
 
     return new_user
 
@@ -217,16 +214,14 @@ def create_local_user_from_apigateway_headers(request):
     sso_id = get_apigateway_sso_id(consumer_username)
     sso_rev = 0
     username = consumer_username
-    temporary_email = '{}@{}'.format(sso_id, app_settings.APP_DOMAIN)
 
-    profile_object = {
+    user_object = {
         'sso_id': sso_id,
         'sso_rev': sso_rev,
-        'username': username,
-        'email': temporary_email
+        'username': username
     }
 
-    new_user = create_local_user_from_object(profile_object)
+    new_user = create_local_user_from_object(user_object)
 
     #setattr(new_user, 'sso_app_profile', get_or_create_user_profile(new_user, Profile, profile_object))
 
@@ -240,16 +235,14 @@ def create_local_user_from_jwt(decoded_jwt):
     sso_id = decoded_jwt.get('sso_id')
     sso_rev = decoded_jwt.get('sso_rev')
     username = decoded_jwt.get('username', sso_id)
-    temporary_email = '{}@{}'.format(sso_id, app_settings.APP_DOMAIN)
 
-    profile_object = {
+    user_object = {
         'sso_id': sso_id,
         'sso_rev': sso_rev,
-        'username': username,
-        'email': temporary_email
+        'username': username
     }
 
-    new_user = create_local_user_from_object(profile_object)
+    new_user = create_local_user_from_object(user_object)
 
     #setattr(new_user, 'sso_app_profile', get_or_create_user_profile(new_user, Profile, profile_object))
 
