@@ -34,7 +34,10 @@ class WebpackBuiltTemplateViewMixin(TemplateView):
 
     def get_template_names(self):
         if app_settings.BACKEND_HAS_CUSTOM_FRONTEND_APP:
-            return ['frontend/built.html']
+            original_template_path = getattr(self, 'template_name')
+            relative_template_path = original_template_path
+
+            return [relative_template_path]
         else:
             return [getattr(self, 'template_name')]
 
