@@ -5,6 +5,7 @@ from random import seed, randint
 import base64
 
 from django.core.management.utils import get_random_secret_key
+from django.conf import settings
 
 from .exceptions import ProfileIncompleteException, DectivatedUserException, UnsubscribedUserException, DjangoStaffUsersCanNotLoginException
 from .permissions import is_authenticated, is_django_staff
@@ -14,8 +15,9 @@ from . import app_settings
 SEED = int(base64.b16encode(bytes(get_random_secret_key(), 'utf-8')), 16)
 seed(SEED)
 
+JWT_COOKIE_SECURE = not settings.DEBUG
 
-def set_cookie(response, key, value, days_expire=None, secure=True):
+def set_cookie(response, key, value, days_expire=None, secure=JWT_COOKIE_SECURE):
     """
     Sets response auth cookie
 
@@ -26,6 +28,7 @@ def set_cookie(response, key, value, days_expire=None, secure=True):
     :param secure:
     :return:
     """
+
     if days_expire is None:
         max_age = app_settings.COOKIE_AGE  # django default
     else:
@@ -48,7 +51,7 @@ def invalidate_cookie(response, key):
     :param key:
     :return:
     """
-    response.set_cookie(key, None, max_age=None, expires='Thu, 01 Jan 1970 00:00:01 GMT', path='/',
+    response.set_cookie(key, '', max_age=None, expires='Thu, 01 Jan 1970 00:00:01 GMT', path='/',
                         domain=app_settings.COOKIE_DOMAIN, secure=None, httponly=False)
 
 
@@ -80,7 +83,7 @@ def get_session_key(request, key, default=None):
     return getattr(request, key, default)
 
 
-def check_user_can_login(user):
+def check_user_can_login(user, skip_profile_checks=False):
     """
     Check user login ability
     :param user:
@@ -96,9 +99,9 @@ def check_user_can_login(user):
             if user.sso_app_profile.is_unsubscribed:
                 raise UnsubscribedUserException()
             else:
-                if app_settings.BACKEND_ENABLED and app_settings.BACKEND_SIGNUP_MUST_FILL_PROFILE:
+                if not skip_profile_checks:
                     if user.sso_app_profile.is_incomplete:
-                        raise ProfileIncompleteException('Must fill in profile.')
+                        raise ProfileIncompleteException(app_settings.PROFILE_COMPLETE_URL)
 
 
 def is_test_user(user):
